==> opensaml-saml-impl-3.4.6-sources.jar: org/opensaml/saml/saml1/core/impl/AttributeQueryBuilder.java <==
/*
 * Licensed to the University Corporation for Advanced Internet Development,
 * Inc. (UCAID) under one or more contributor license agreements.  See the
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opensaml.saml.saml1.core.impl;

import org.opensaml.saml.common.AbstractSAMLObjectBuilder;
import org.opensaml.saml.common.xml.SAMLConstants;
import org.opensaml.saml.saml1.core.AttributeQuery;

/**
 * Builder of {@link org.opensaml.saml.saml1.core.impl.AttributeQueryImpl} objects.
 */
public class AttributeQueryBuilder extends AbstractSAMLObjectBuilder<AttributeQuery> {

    /**
     * Constructor.
     */
    public AttributeQueryBuilder() {

    }

    /** {@inheritDoc} */
    public AttributeQuery buildObject() {
        return buildObject(SAMLConstants.SAML10P_NS, AttributeQuery.DEFAULT_ELEMENT_LOCAL_NAME,
                SAMLConstants.SAML1P_PREFIX);
    }

    /** {@inheritDoc} */
    public AttributeQuery buildObject(final String namespaceURI, final String localName, final String namespacePrefix) {
        return new AttributeQueryImpl(namespaceURI, localName, namespacePrefix);
    }
}

==> opensaml-saml-impl-5.1.6-sources.jar: org/opensaml/saml/saml1/core/impl/AttributeQueryBuilder.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opensaml.saml.saml1.core.impl;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;

import org.opensaml.saml.common.AbstractSAMLObjectBuilder;
import org.opensaml.saml.common.xml.SAMLConstants;
import org.opensaml.saml.saml1.core.AttributeQuery;

/**
 * Builder of {@link AttributeQuery} objects.
 */
public class AttributeQueryBuilder extends AbstractSAMLObjectBuilder<AttributeQuery> {

    /** {@inheritDoc} */
    @Override
    @Nonnull public AttributeQuery buildObject() {
        return buildObject(SAMLConstants.SAML10P_NS, AttributeQuery.DEFAULT_ELEMENT_LOCAL_NAME,
                SAMLConstants.SAML1P_PREFIX);
    }

    /** {@inheritDoc} */
    @Override
    @Nonnull public AttributeQuery buildObject(@Nullable final String namespaceURI, @Nonnull final String localName,
            @Nullable final String namespacePrefix) {
        return new AttributeQueryImpl(namespaceURI, localName, namespacePrefix);
    }

}
